==> fet_5.14.3.orig.tar.gz: fet-5.14.3/src/interface/addconstraintstudentsmaxhourscontinuouslyform.h <==
/***************************************************************************
                          addconstraintstudentsmaxhourscontinuouslyform.h  -  description
                             -------------------
    begin                : 19 July 2007
    copyright            : (C) 2007 by Lalescu Liviu
    email                : Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef ADDCONSTRAINTSTUDENTSMAXHOURSCONTINUOUSLYFORM_H
#define ADDCONSTRAINTSTUDENTSMAXHOURSCONTINUOUSLYFORM_H

#include "ui_addconstraintstudentsmaxhourscontinuouslyform_template.h"
#include "timetable_defs.h"
#include "timetable.h"
#include "fet.h"

class AddConstraintStudentsMaxHoursContinuouslyForm : public QDialog, Ui::AddConstraintStudentsMaxHoursContinuouslyForm_template  {
	Q_OBJECT
public:
	AddConstraintStudentsMaxHoursContinuouslyForm();
	~AddConstraintStudentsMaxHoursContinuouslyForm();

public slots:
	void constraintChanged();
	void addCurrentConstraint();
};

#endif

==> fet_5.18.0.orig.tar.gz: fet-5.18.0/src/interface/addconstraintstudentsmaxhourscontinuouslyform.h <==
/***************************************************************************
                          addconstraintstudentsmaxhourscontinuouslyform.h  -  description
                             -------------------
    begin                : 19 July 2007
    copyright            : (C) 2007 by Lalescu Liviu
    email                : Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef ADDCONSTRAINTSTUDENTSMAXHOURSCONTINUOUSLYFORM_H
#define ADDCONSTRAINTSTUDENTSMAXHOURSCONTINUOUSLYFORM_H

#include "ui_addconstraintstudentsmaxhourscontinuouslyform_template.h"
#include "timetable_defs.h"
#include "timetable.h"
#include "fet.h"

class AddConstraintStudentsMaxHoursContinuouslyForm : public QDialog, Ui::AddConstraintStudentsMaxHoursContinuouslyForm_template  {
	Q_OBJECT
public:
	AddConstraintStudentsMaxHoursContinuouslyForm(QWidget* parent);
	~AddConstraintStudentsMaxHoursContinuouslyForm();

public slots:
	void constraintChanged();
	void addCurrentConstraint();
};

#endif
